==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AWSPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSPlatformStatusFluent<A extends AWSPlatformStatusFluent<A>> extends Fluent<A>{
  public String getRegion();
  public A withRegion(String region);
  public Boolean hasRegion();
  public A addToResourceTags(Integer index,AWSResourceTag item);
  public A setToResourceTags(Integer index,AWSResourceTag item);
  public A addToResourceTags(io.fabric8.openshift.api.model.config.v1.AWSResourceTag... items);
  public A addAllToResourceTags(Collection<AWSResourceTag> items);
  public A removeFromResourceTags(io.fabric8.openshift.api.model.config.v1.AWSResourceTag... items);
  public A removeAllFromResourceTags(Collection<AWSResourceTag> items);
  public A removeMatchingFromResourceTags(Predicate<AWSResourceTagBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceTags instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSResourceTag> getResourceTags();
  public List<AWSResourceTag> buildResourceTags();
  public AWSResourceTag buildResourceTag(Integer index);
  public AWSResourceTag buildFirstResourceTag();
  public AWSResourceTag buildLastResourceTag();
  public AWSResourceTag buildMatchingResourceTag(Predicate<AWSResourceTagBuilder> predicate);
  public Boolean hasMatchingResourceTag(Predicate<AWSResourceTagBuilder> predicate);
  public A withResourceTags(List<AWSResourceTag> resourceTags);
  public A withResourceTags(io.fabric8.openshift.api.model.config.v1.AWSResourceTag... resourceTags);
  public Boolean hasResourceTags();
  public A addNewResourceTag(String key,String value);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTag();
  public AWSPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTagLike(AWSResourceTag item);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> setNewResourceTagLike(Integer index,AWSResourceTag item);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editResourceTag(Integer index);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editFirstResourceTag();
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editLastResourceTag();
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editMatchingResourceTag(Predicate<AWSResourceTagBuilder> predicate);
  public A addToServiceEndpoints(Integer index,AWSServiceEndpoint item);
  public A setToServiceEndpoints(Integer index,AWSServiceEndpoint item);
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A addAllToServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A removeAllFromServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeMatchingFromServiceEndpoints(Predicate<AWSServiceEndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSServiceEndpoint> getServiceEndpoints();
  public List<AWSServiceEndpoint> buildServiceEndpoints();
  public AWSServiceEndpoint buildServiceEndpoint(Integer index);
  public AWSServiceEndpoint buildFirstServiceEndpoint();
  public AWSServiceEndpoint buildLastServiceEndpoint();
  public AWSServiceEndpoint buildMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public Boolean hasMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A withServiceEndpoints(List<AWSServiceEndpoint> serviceEndpoints);
  public A withServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... serviceEndpoints);
  public Boolean hasServiceEndpoints();
  public A addNewServiceEndpoint(String name,String url);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> addNewServiceEndpoint();
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(AWSServiceEndpoint item);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(Integer index,AWSServiceEndpoint item);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editServiceEndpoint(Integer index);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint();
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editLastServiceEndpoint();
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceTagsNested<N> extends Nested<N>,AWSResourceTagFluent<AWSPlatformStatusFluent.ResourceTagsNested<N>>{
    public N and();
    public N endResourceTag();
    
  }
  public interface ServiceEndpointsNested<N> extends Nested<N>,AWSServiceEndpointFluent<AWSPlatformStatusFluent.ServiceEndpointsNested<N>>{
    public N and();
    public N endServiceEndpoint();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AWSPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSPlatformStatusFluent<A extends AWSPlatformStatusFluent<A>> extends Fluent<A>{
  public String getRegion();
  public A withRegion(String region);
  public Boolean hasRegion();
  public A addToResourceTags(int index,AWSResourceTag item);
  public A setToResourceTags(int index,AWSResourceTag item);
  public A addToResourceTags(io.fabric8.openshift.api.model.config.v1.AWSResourceTag... items);
  public A addAllToResourceTags(Collection<AWSResourceTag> items);
  public A removeFromResourceTags(io.fabric8.openshift.api.model.config.v1.AWSResourceTag... items);
  public A removeAllFromResourceTags(Collection<AWSResourceTag> items);
  public A removeMatchingFromResourceTags(Predicate<AWSResourceTagBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceTags instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSResourceTag> getResourceTags();
  public List<AWSResourceTag> buildResourceTags();
  public AWSResourceTag buildResourceTag(int index);
  public AWSResourceTag buildFirstResourceTag();
  public AWSResourceTag buildLastResourceTag();
  public AWSResourceTag buildMatchingResourceTag(Predicate<AWSResourceTagBuilder> predicate);
  public Boolean hasMatchingResourceTag(Predicate<AWSResourceTagBuilder> predicate);
  public A withResourceTags(List<AWSResourceTag> resourceTags);
  public A withResourceTags(io.fabric8.openshift.api.model.config.v1.AWSResourceTag... resourceTags);
  public Boolean hasResourceTags();
  public A addNewResourceTag(String key,String value);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTag();
  public AWSPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTagLike(AWSResourceTag item);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> setNewResourceTagLike(int index,AWSResourceTag item);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editResourceTag(int index);
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editFirstResourceTag();
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editLastResourceTag();
  public AWSPlatformStatusFluent.ResourceTagsNested<A> editMatchingResourceTag(Predicate<AWSResourceTagBuilder> predicate);
  public A addToServiceEndpoints(int index,AWSServiceEndpoint item);
  public A setToServiceEndpoints(int index,AWSServiceEndpoint item);
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A addAllToServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A removeAllFromServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeMatchingFromServiceEndpoints(Predicate<AWSServiceEndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSServiceEndpoint> getServiceEndpoints();
  public List<AWSServiceEndpoint> buildServiceEndpoints();
  public AWSServiceEndpoint buildServiceEndpoint(int index);
  public AWSServiceEndpoint buildFirstServiceEndpoint();
  public AWSServiceEndpoint buildLastServiceEndpoint();
  public AWSServiceEndpoint buildMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public Boolean hasMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A withServiceEndpoints(List<AWSServiceEndpoint> serviceEndpoints);
  public A withServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... serviceEndpoints);
  public Boolean hasServiceEndpoints();
  public A addNewServiceEndpoint(String name,String url);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> addNewServiceEndpoint();
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(AWSServiceEndpoint item);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(int index,AWSServiceEndpoint item);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editServiceEndpoint(int index);
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint();
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editLastServiceEndpoint();
  public AWSPlatformStatusFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceTagsNested<N> extends Nested<N>,AWSResourceTagFluent<AWSPlatformStatusFluent.ResourceTagsNested<N>>{
    public N and();
    public N endResourceTag();
    
  }
  public interface ServiceEndpointsNested<N> extends Nested<N>,AWSServiceEndpointFluent<AWSPlatformStatusFluent.ServiceEndpointsNested<N>>{
    public N and();
    public N endServiceEndpoint();
    
  }
  
}
